@@ -101,6 +101,16 @@ class Default(protocol.RSEProtocol):
         """
         pass
 
+    def bulk_delete(self, pfns):
+        """
+            Submits an async task to bulk delete files.
+
+            :param pfns: list of pfns to delete
+
+            :raises TransferAPIError: if unexpected response from the service.
+        """
+        pass
+
     def rename(self, pfn, new_pfn):
         """ Allows to rename a file stored inside the connected RSE.
 
